==> hippoagentsdk-0.1.3-sources.jar: com/hippoagent/confcall/HungUpBroadcast.kt <==
package com.hippoagent.confcall

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import androidx.localbroadcastmanager.content.LocalBroadcastManager
import com.hippoagent.BuildConfig
import com.hippoagent.HippoApplication
import com.hippoagent.datastructure.FuguAppConstant
import com.hippoagent.hippocall.CommonData
import com.hippoagent.hippocall.HippoCallConfig
import com.hippoagent.hippocall.WebRTCCallConstants
import com.hippoagent.hippocall.WebRTCCallConstants.Companion.DEVICE_PAYLOAD
import com.hippoagent.utils.UniqueIMEIID
import org.json.JSONObject

class HungUpBroadcast : BroadcastReceiver() {
    override fun onReceive(context: Context?, intent: Intent?) {

        if (intent?.getStringExtra("action").equals("rejectCall")) {
            val startIntent = Intent(context, OngoingCallService::class.java)
            context?.stopService(startIntent)

            val userId = HippoApplication.getInstance().userData.userId
            val devicePayload = JSONObject()
            try {
                devicePayload.put(FuguAppConstant.DEVICE_ID, UniqueIMEIID.getUniqueIMEIId(context))
                devicePayload.put(FuguAppConstant.DEVICE_TYPE, FuguAppConstant.ANDROID_USER)
                devicePayload.put(FuguAppConstant.APP_VERSION, BuildConfig.VERSION_NAME)
                devicePayload.put(FuguAppConstant.DEVICE_DETAILS, CommonData.deviceDetails(context))
            } catch (e: Exception) {
                e.printStackTrace()
            }


            val startCallJson = JSONObject()
            startCallJson.put(FuguAppConstant.IS_SILENT, true)
            startCallJson.put(WebRTCCallConstants.VIDEO_CALL_TYPE, WebRTCCallConstants.JitsiCallType.REJECT_CONFERENCE.toString())
            startCallJson.put(FuguAppConstant.USER_ID, userId)
            startCallJson.put(FuguAppConstant.CHANNEL_ID, intent?.getLongExtra(FuguAppConstant.CHANNEL_ID, -1L))
            startCallJson.put(WebRTCCallConstants.MESSAGE_TYPE, WebRTCCallConstants.VIDEO_CALL)
            startCallJson.put(WebRTCCallConstants.CALL_TYPE, "VIDEO")
            startCallJson.put(WebRTCCallConstants.MESSAGE_UNIQUE_ID, intent?.getStringExtra(FuguAppConstant.MESSAGE_UNIQUE_ID))
            startCallJson.put(WebRTCCallConstants.DEVICE_PAYLOAD, devicePayload)
            startCallJson.put(WebRTCCallConstants.DEVICE_ID, UniqueIMEIID.getUniqueIMEIId(context))
            startCallJson.put(FuguAppConstant.INVITE_LINK, intent?.getStringExtra(FuguAppConstant.INVITE_LINK))

            startCallJson.put("message", "")
            startCallJson.put("is_typing", FuguAppConstant.TYPING_SHOW_MESSAGE)
            startCallJson.put("user_type", FuguAppConstant.ANDROID_USER)
            if (intent?.hasExtra(DEVICE_PAYLOAD)!!) {
                HippoCallConfig.getInstance().sendMessage(intent?.getLongExtra(FuguAppConstant.CHANNEL_ID, -1L), startCallJson)
            }

            try {
                HippoAudioManager.getInstance(context).stop(false)
            } catch (e: Exception) {
            }

            OngoingCallService.NotificationServiceState.isConferenceServiceRunning = false
            OngoingCallService.NotificationServiceState.isConferenceConnected = false
            OngoingCallService.NotificationServiceState.transactionId = ""

            OngoingCallService.CallState.readyToConnect = 0
            OngoingCallService.CallState.muid = ""
        } else if(intent?.getStringExtra("action").equals("hungupCall")) {
            try {
                val mIntent = Intent("CALL_HANGUP")
                LocalBroadcastManager.getInstance(context!!).sendBroadcast(mIntent)
            } catch (e: Exception) {
            }

            val startIntent = Intent(context, OngoingCallService::class.java)
            context?.stopService(startIntent)

            val userId = HippoApplication.getInstance().userData.userId
            val devicePayload = JSONObject()
            try {
                devicePayload.put(FuguAppConstant.DEVICE_ID, UniqueIMEIID.getUniqueIMEIId(context))
                devicePayload.put(FuguAppConstant.DEVICE_TYPE, FuguAppConstant.ANDROID_USER)
                devicePayload.put(FuguAppConstant.APP_VERSION, BuildConfig.VERSION_NAME)
                devicePayload.put(FuguAppConstant.DEVICE_DETAILS, CommonData.deviceDetails(context))
            } catch (e: Exception) {
                e.printStackTrace()
            }


            val startCallJson = JSONObject()
            startCallJson.put(FuguAppConstant.IS_SILENT, true)
            startCallJson.put(WebRTCCallConstants.VIDEO_CALL_TYPE, WebRTCCallConstants.JitsiCallType.HUNGUP_CONFERENCE.toString())
            startCallJson.put(FuguAppConstant.USER_ID, userId)
            startCallJson.put(FuguAppConstant.CHANNEL_ID, intent?.getLongExtra(FuguAppConstant.CHANNEL_ID, -1L))
            startCallJson.put(WebRTCCallConstants.MESSAGE_TYPE, WebRTCCallConstants.VIDEO_CALL)
            startCallJson.put(WebRTCCallConstants.CALL_TYPE, "VIDEO")
            startCallJson.put(WebRTCCallConstants.MESSAGE_UNIQUE_ID, intent?.getStringExtra(FuguAppConstant.MESSAGE_UNIQUE_ID))
            startCallJson.put(WebRTCCallConstants.DEVICE_PAYLOAD, devicePayload)
            startCallJson.put(WebRTCCallConstants.DEVICE_ID, UniqueIMEIID.getUniqueIMEIId(context))
            startCallJson.put(FuguAppConstant.INVITE_LINK, intent?.getStringExtra(FuguAppConstant.INVITE_LINK))

            startCallJson.put("message", "")
            startCallJson.put("is_typing", FuguAppConstant.TYPING_SHOW_MESSAGE)
            startCallJson.put("user_type", FuguAppConstant.ANDROID_USER)
            if (intent?.hasExtra(DEVICE_PAYLOAD)!!) {
                HippoCallConfig.getInstance().sendMessage(intent?.getLongExtra(FuguAppConstant.CHANNEL_ID, -1L), startCallJson)
            }

            OngoingCallService.NotificationServiceState.isConferenceServiceRunning = false
            OngoingCallService.NotificationServiceState.isConferenceConnected = false
            OngoingCallService.NotificationServiceState.transactionId = ""
            OngoingCallService.CallState.readyToConnect = 0
            OngoingCallService.CallState.muid = ""

        } else if(intent?.getStringExtra("action").equals("endSession")) {
            val startIntent = Intent(context, OngoingCallService::class.java)
            context?.stopService(startIntent)

            OngoingCallService.NotificationServiceState.isConferenceServiceRunning = false
            OngoingCallService.NotificationServiceState.isConferenceConnected = false
            OngoingCallService.NotificationServiceState.transactionId = ""
        }


    }
}

==> hippoagentsdk-3.0.5.1-sources.jar: com/hippoagent/confcall/HungUpBroadcast.kt <==
package com.hippoagent.confcall

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.text.TextUtils
import androidx.localbroadcastmanager.content.LocalBroadcastManager
import com.hippoagent.BuildConfig
import com.hippoagent.HippoApplication
import com.hippoagent.datastructure.FuguAppConstant
import com.hippoagent.hippocall.CommonData
import com.hippoagent.hippocall.HippoCallConfig
import com.hippoagent.hippocall.WebRTCCallConstants
import com.hippoagent.hippocall.WebRTCCallConstants.Companion.DEVICE_PAYLOAD
import com.hippoagent.utils.UniqueIMEIID
import org.json.JSONObject

class HungUpBroadcast : BroadcastReceiver() {
    override fun onReceive(context: Context?, intent: Intent?) {

        if (intent?.getStringExtra("action").equals("rejectCall")) {
            val startIntent = Intent(context, OngoingCallService::class.java)
            context?.stopService(startIntent)

            val userId = HippoApplication.getInstance().userData.userId
            val devicePayload = JSONObject()
            try {
                devicePayload.put(FuguAppConstant.DEVICE_ID, UniqueIMEIID.getUniqueIMEIId(context))
                devicePayload.put(FuguAppConstant.DEVICE_TYPE, FuguAppConstant.ANDROID_USER)
                devicePayload.put(FuguAppConstant.APP_VERSION, BuildConfig.VERSION_NAME)
                devicePayload.put(FuguAppConstant.DEVICE_DETAILS, CommonData.deviceDetails(context))
            } catch (e: Exception) {
                e.printStackTrace()
            }


            val startCallJson = JSONObject()
            startCallJson.put(FuguAppConstant.IS_SILENT, true)
            startCallJson.put(
                WebRTCCallConstants.VIDEO_CALL_TYPE,
                WebRTCCallConstants.JitsiCallType.REJECT_CONFERENCE.toString()
            )
            startCallJson.put(FuguAppConstant.USER_ID, userId)
            startCallJson.put(
                FuguAppConstant.CHANNEL_ID,
                intent?.getLongExtra(FuguAppConstant.CHANNEL_ID, -1L)
            )
            startCallJson.put(WebRTCCallConstants.MESSAGE_TYPE, WebRTCCallConstants.VIDEO_CALL)
            startCallJson.put(WebRTCCallConstants.CALL_TYPE, "VIDEO")
            startCallJson.put(
                WebRTCCallConstants.MESSAGE_UNIQUE_ID,
                intent?.getStringExtra(FuguAppConstant.MESSAGE_UNIQUE_ID)
            )
            startCallJson.put(WebRTCCallConstants.DEVICE_PAYLOAD, devicePayload)
            startCallJson.put(WebRTCCallConstants.DEVICE_ID, UniqueIMEIID.getUniqueIMEIId(context))
            startCallJson.put(
                FuguAppConstant.INVITE_LINK,
                intent?.getStringExtra(FuguAppConstant.INVITE_LINK)
            )

            startCallJson.put("message", "")
            startCallJson.put("is_typing", FuguAppConstant.TYPING_SHOW_MESSAGE)
            startCallJson.put("user_type", FuguAppConstant.ANDROID_USER)
            startCallJson.put("auth0", intent?.getStringExtra(FuguAppConstant.MESSAGE_AUTH_ID))
            if (TextUtils.isEmpty(intent?.getStringExtra(FuguAppConstant.MESSAGE_AUTH_ID))) {
                if (!TextUtils.isEmpty(OngoingCallService.NotificationServiceState.authObj))
                    startCallJson.put("auth0", OngoingCallService.NotificationServiceState.authObj)
                else
                    startCallJson.remove("auth0")
            }

            if (intent?.hasExtra(DEVICE_PAYLOAD)!!) {
                HippoCallConfig.getInstance().sendMessage(
                    intent?.getLongExtra(FuguAppConstant.CHANNEL_ID, -1L),
                    startCallJson
                )
            }

            try {
                HippoAudioManager.getInstance(context).stop(false)
            } catch (e: Exception) {
            }

            OngoingCallService.NotificationServiceState.isConferenceServiceRunning = false
            OngoingCallService.NotificationServiceState.isConferenceConnected = false
            OngoingCallService.NotificationServiceState.transactionId = ""
            OngoingCallService.NotificationServiceState.authObj = ""

            OngoingCallService.CallState.readyToConnect = 0
            OngoingCallService.CallState.muid = ""
        } else if (intent?.getStringExtra("action").equals("hungupCall")) {
            try {
                val mIntent = Intent("CALL_HANGUP")
                LocalBroadcastManager.getInstance(context!!).sendBroadcast(mIntent)
            } catch (e: Exception) {
                e.printStackTrace()
            }

            val startIntent = Intent(context, OngoingCallService::class.java)
            context?.stopService(startIntent)

            val userId = HippoApplication.getInstance().userData.userId
            val devicePayload = JSONObject()
            try {
                devicePayload.put(FuguAppConstant.DEVICE_ID, UniqueIMEIID.getUniqueIMEIId(context))
                devicePayload.put(FuguAppConstant.DEVICE_TYPE, FuguAppConstant.ANDROID_USER)
                devicePayload.put(FuguAppConstant.APP_VERSION, BuildConfig.VERSION_NAME)
                devicePayload.put(FuguAppConstant.DEVICE_DETAILS, CommonData.deviceDetails(context))
            } catch (e: Exception) {
                e.printStackTrace()
            }


            val startCallJson = JSONObject()
            startCallJson.put(FuguAppConstant.IS_SILENT, true)
            startCallJson.put(
                WebRTCCallConstants.VIDEO_CALL_TYPE,
                WebRTCCallConstants.JitsiCallType.HUNGUP_CONFERENCE.toString()
            )
            startCallJson.put(FuguAppConstant.USER_ID, userId)
            startCallJson.put(
                FuguAppConstant.CHANNEL_ID,
                intent?.getLongExtra(FuguAppConstant.CHANNEL_ID, -1L)
            )
            startCallJson.put(WebRTCCallConstants.MESSAGE_TYPE, WebRTCCallConstants.VIDEO_CALL)
            startCallJson.put(WebRTCCallConstants.CALL_TYPE, "VIDEO")
            startCallJson.put(
                WebRTCCallConstants.MESSAGE_UNIQUE_ID,
                intent?.getStringExtra(FuguAppConstant.MESSAGE_UNIQUE_ID)
            )
            startCallJson.put(WebRTCCallConstants.DEVICE_PAYLOAD, devicePayload)
            startCallJson.put(WebRTCCallConstants.DEVICE_ID, UniqueIMEIID.getUniqueIMEIId(context))
            startCallJson.put(
                FuguAppConstant.INVITE_LINK,
                intent?.getStringExtra(FuguAppConstant.INVITE_LINK)
            )
            startCallJson.put("auth0", intent?.getStringExtra(FuguAppConstant.MESSAGE_AUTH_ID))
            if (TextUtils.isEmpty(intent?.getStringExtra(FuguAppConstant.MESSAGE_AUTH_ID))) {
                if (!TextUtils.isEmpty(OngoingCallService.NotificationServiceState.authObj))
                    startCallJson.put("auth0", OngoingCallService.NotificationServiceState.authObj)
                else
                    startCallJson.remove("auth0")
            }
            startCallJson.put("message", "")
            startCallJson.put("is_typing", FuguAppConstant.TYPING_SHOW_MESSAGE)
            startCallJson.put("user_type", FuguAppConstant.ANDROID_USER)
            if (intent?.hasExtra(DEVICE_PAYLOAD)!!) {
                HippoCallConfig.getInstance().sendMessage(
                    intent?.getLongExtra(FuguAppConstant.CHANNEL_ID, -1L),
                    startCallJson
                )
            }

            OngoingCallService.NotificationServiceState.isConferenceServiceRunning = false
            OngoingCallService.NotificationServiceState.isConferenceConnected = false
            OngoingCallService.NotificationServiceState.transactionId = ""
            OngoingCallService.CallState.readyToConnect = 0
            OngoingCallService.CallState.muid = ""

        } else if (intent?.getStringExtra("action").equals("endSession")) {
            val startIntent = Intent(context, OngoingCallService::class.java)
            context?.stopService(startIntent)

            OngoingCallService.NotificationServiceState.isConferenceServiceRunning = false
            OngoingCallService.NotificationServiceState.isConferenceConnected = false
            OngoingCallService.NotificationServiceState.transactionId = ""
            OngoingCallService.NotificationServiceState.authObj = ""

        }


    }
}
